# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0] - 2020-12-08
### Added
- MQTT client reporting measurements of FT017TH wireless thermo/hygrometers

[Unreleased]: https://github.com/fphammerle/wireless-sensor-mqtt/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/fphammerle/wireless-sensor-mqtt/releases/tag/v0.1.0
